@@ -47,22 +47,18 @@ class VideoFileClip(VideoClip):
         
         # Make some of the reader's attributes accessible from the clip
         self.duration = self.reader.duration
+        self.end = self.reader.duration
+        
         self.fps = self.reader.fps
         self.size = self.reader.size
         self.get_frame = lambda t: self.reader.get_frame(t)
         
         # Make a reader for the audio, if any.
         if audio:
-            try:
-                self.audio = AudioFileClip(filename,
-                                           buffersize= audio_buffersize,
-                                           fps = audio_fps,
-                                           nbytes = audio_nbytes)
-            except:
-                if verbose:
-                    print "No audio found in %s"%filename
-                pass
-                
+            self.audio = AudioFileClip(filename,
+                                       buffersize= audio_buffersize,
+                                       fps = audio_fps,
+                                       nbytes = audio_nbytes)
     
     def coreader(self, audio=True):
         """ Returns a copy of the AudioFileClip, i.e. a new entrance point
